pub enum Error {
Show 21 variants UnsupportedOperator(String), CanNotExec(Operator), StartWithNonValueOperator, UnpairedBrackets, DuplicateValueNode, DuplicateOperatorNode, CommaNotWithFunction, BracketNotWithFunction, FunctionNotExists(String), ExpectedBoolean(Value), ExpectedIdentifier, ExpectedArray, ExpectedObject, ExpectedNumber, NoFinalNode, ArgumentsGreater(usize), ArgumentsLess(usize), UnsupportedTypes(StringString), InvalidRange(String), CanNotAddChild, Custom(String),
}
Expression parsing error

Variants

UnsupportedOperator(String)

Unsupported operator yet.

CanNotExec(Operator)

This operator does not support execution.

StartWithNonValueOperator

Your expression may start with non-value operator like ( + * )

UnpairedBrackets

Unpaired brackets, left brackets count does not equal right brackets count

DuplicateValueNode

Duplicate values node, you may have (2 3) but there is no operators between them

DuplicateOperatorNode

Duplicate operators node, you may have (+ +) but there is no values between them

CommaNotWithFunction

You have a comma(,) , but there is no function in front of it.

BracketNotWithFunction

You have empty brackets () , but there is no function in front of it.

FunctionNotExists(String)

Function not exists.

ExpectedBoolean(Value)

Expected a boolean but the given value isn’t.

ExpectedIdentifier

Expected ident.

ExpectedArray

Expected array.

ExpectedObject

Expected object.

ExpectedNumber

Expect number.

NoFinalNode

Failed to parse, no final expression.

ArgumentsGreater(usize)

The number of arguments is greater than the maximum limit.

ArgumentsLess(usize)

The number of arguments is less than the minimum limit.

UnsupportedTypes(StringString)

This two value types are different or do not support mathematical calculations.

InvalidRange(String)

Invalid range expression like 1..2..3

CanNotAddChild

Can not add child node.

Custom(String)

Custom error.